<?php
/*
 * *************************************************************************
 *  * Copyright (C) JK-Studio, Inc - All Rights Reserved
 *  *
 *  * @file        pagination.php
 *  * @author      Alexander Poslushnyak
 *  * @website     https://jk-studio-dev.com/
 *  * @date        8/15/21, 12:22 AM
 *
 */

/**
 * Pagination - Show numbered pagination for catalog pages
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/loop/pagination.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce\Templates
 * @version 3.3.1
 */

if (!defined('ABSPATH')) {
    exit;
}

$total = isset($total) ? $total : wc_get_loop_prop('total_pages');
$current = isset($current) ? $current : wc_get_loop_prop('current_page');
$base = isset($base) ? $base : esc_url_raw(str_replace(999999999, '%#%', remove_query_arg('add-to-cart', get_pagenum_link(999999999, false))));
$format = isset($format) ? $format : '';

if ($total <= 1) {
    return;
}

$pagination_type = get_theme_mod('shop-pagination-type', esc_attr('default'));

$pagination_direction = get_theme_mod('shop-pagination-alignment', esc_attr('left'));


$classes = array();

array_push($classes, 'pagination-' . $pagination_type);

array_push($classes, 'pagination-direction-' . $pagination_direction);

$classes = implode(' ', $classes);

?>
<nav class="jk-pagination pagination-<?php echo esc_attr($classes); ?>">

    <?php

    if ($pagination_type === 'default'):

        echo paginate_links(
            apply_filters(
                'woocommerce_pagination_args',
                array( // WPCS: XSS ok.
                    'base' => $base,
                    'format' => $format,
                    'add_args' => false,
                    'current' => max(1, $current),
                    'total' => $total,
                    'prev_text' => '<div class="pagination-arrow prev-arrow"><i class="ri-arrow-left-line"></i></div>',
                    'next_text' => '<div class="pagination-arrow next-arrow"><i class="ri-arrow-right-line"></i></div>',
                    'type' => 'list',
                    'end_size' => 1,
                    'mid_size' => 1,
                )
            )
        );

    elseif ($pagination_type === 'load-more'):

        ?>

        <button class="jk-button default-style animation-slide load-more-button">

            <span>

                <span>

                    <?php echo esc_html__('Load More', 'qreatix'); ?>

                </span>

            </span>

        </button>

    <?php

    endif;

    ?>

</nav>
