<?php
/*
 * *************************************************************************
 *  * Copyright (C) JK-Studio, Inc - All Rights Reserved
 *  *
 *  * @file        product-image.php
 *  * @author      Alexander Poslushnyak
 *  * @website     https://jk-studio-dev.com/
 *  * @date        8/15/21, 12:22 AM
 *
 */

/**
 * Single Product Image
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/single-product/product-image.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce\Templates
 * @version 3.5.1
 */

defined('ABSPATH') || exit;

// Note: `wc_get_gallery_image_html` was added in WC 3.3.2 and did not exist prior. This check protects against theme overrides being used on older versions of WC.
if (!function_exists('wc_get_gallery_image_html')) {
    return;
}

global $product;

$columns = apply_filters('woocommerce_product_thumbnails_columns', 4);
$post_thumbnail_id = $product->get_image_id();
$wrapper_classes = apply_filters(
    'woocommerce_single_product_image_gallery_classes',
    array(
        'woocommerce-product-gallery',
        'woocommerce-product-gallery--' . ($post_thumbnail_id ? 'with-images' : 'without-images'),
        'woocommerce-product-gallery--columns-' . absint($columns),
        'images',
    )
);

$attachment_ids = $product->get_gallery_image_ids();

$zoom_toggle = get_theme_mod('shop-product-zoom-toggle', esc_attr(1));

?>
<div class="<?php echo esc_attr(implode(' ', array_map('sanitize_html_class', $wrapper_classes))); ?>"
     data-columns="<?php echo esc_attr($columns); ?>" style="opacity: 0; transition: opacity .25s ease-in-out;">
    <figure class="woocommerce-product-gallery__wrapper">

        <?php

        if (!empty($attachment_ids)):

            array_push($attachment_ids, $post_thumbnail_id);

            $attachment_ids = array_reverse($attachment_ids);

            ?>

            <div class="thumbnails-slider-wrapper">

                <?php if (count($attachment_ids) > 4): ?>

                    <div class="navigation-button navigation-button-prev">

                        <i class="ri-arrow-up-line"></i>

                    </div>

                <?php endif; ?>

                <div class="swiper-container products-thumbnails-slider">

                    <div class="swiper-wrapper">

                        <?php

                        if ($attachment_ids && $product->get_image_id()) {
                            foreach ($attachment_ids as $attachment_id) {
                                ?>

                                <div class="swiper-slide">

                                    <?php

                                    if (class_exists('JKD_Helper')):

                                        echo JKD_Helper::render_image($attachment_id,
                                            'jk-square-size-medium',
                                            array('sizes' => implode(',', array(
                                                '(max-width: 300px) 300px',
                                                '(max-width: 540px) 540px',
                                                '(max-width: 768px) 768px',
                                            )),
                                                'srcset' => implode(',', array(
                                                    esc_url(wp_get_attachment_image_url($attachment_id, 'jk-square-size-extra-small')) . ' 300w',
                                                    esc_url(wp_get_attachment_image_url($attachment_id, 'jk-square-size-small')) . ' 540w',
                                                    esc_url(wp_get_attachment_image_url($attachment_id, 'jk-square-size-medium')) . ' 768w',
                                                )),
                                                'loading' => 'lazy',
                                                'class' => 'wp-image-slider',
                                                'alt' => get_the_title()
                                            ), false);

                                    else:

                                        ?>

                                        <img src="<?php echo esc_url(wp_get_attachment_image_url($attachment_id, 'large')); ?>"
                                             alt="<?php echo esc_attr(get_the_title()); ?>">

                                    <?php

                                    endif;

                                    ?>

                                </div>

                                <?php
                            }
                        }

                        ?>

                    </div>

                </div>

                <?php if (count($attachment_ids) > 4): ?>

                    <div class="navigation-button navigation-button-next">

                        <i class="ri-arrow-down-line"></i>

                    </div>

                <?php endif; ?>

            </div>

        <?php endif; ?>

        <?php if (!empty($attachment_ids)): ?>

            <div class="image-wrapper ">

                <div class="swiper-container products-gallery-slider">

                    <div class="swiper-wrapper">

                        <?php

                        if ($attachment_ids && $product->get_image_id()) {
                            foreach ($attachment_ids as $attachment_id) {
                                ?>

                                <div class="swiper-slide">

                                    <?php if ($zoom_toggle): ?>

                                    <div class="zoom-wrapper"
                                         data-zoom-value="2"
                                         data-zoom-url="<?php echo esc_url(wp_get_attachment_image_url($attachment_id, 'jk-square-size-medium')); ?>">

                                        <?php

                                        endif;

                                        if (class_exists('JKD_Helper')):

                                            echo JKD_Helper::render_image($attachment_id,
                                                'jk-vertical-size-medium',
                                                array('sizes' => implode(',', array(
                                                    '(max-width: 300px) 300px',
                                                    '(max-width: 540px) 540px',
                                                    '(max-width: 768px) 768px',
                                                )),
                                                    'srcset' => implode(',', array(
                                                        esc_url(wp_get_attachment_image_url($attachment_id, 'jk-vertical-size-extra-small')) . ' 300w',
                                                        esc_url(wp_get_attachment_image_url($attachment_id, 'jk-vertical-size-small')) . ' 540w',
                                                        esc_url(wp_get_attachment_image_url($attachment_id, 'jk-vertical-size-medium')) . ' 768w',
                                                    )),
                                                    'loading' => 'lazy',
                                                    'class' => 'wp-image-slider',
                                                    'alt' => get_the_title()
                                                ), false);

                                        else:

                                            ?>

                                            <img src="<?php echo esc_url(wp_get_attachment_image_url($attachment_id, 'large')); ?>"
                                                 alt="<?php echo esc_attr(get_the_title()); ?>">

                                        <?php

                                        endif;

                                        if ($zoom_toggle):

                                        ?>

                                    </div>

                                <?php endif; ?>

                                </div>

                                <?php
                            }
                        }

                        ?>

                    </div>

                    <div class="pagination-numbers">

                    </div>

                </div>

            </div>

        <?php

        else:

            ?>

            <div class="image-wrapper">

                <div class="zoom-wrapper"
                     data-zoom-value="2"
                     data-zoom-url="<?php echo esc_url(wp_get_attachment_image_url($post_thumbnail_id, 'jk-square-size-large')); ?>">

                    <?php

                    if (class_exists('JKD_Helper')):

                        echo JKD_Helper::render_image($post_thumbnail_id,
                            'jk-square-size-large',
                            array('sizes' => implode(',', array(
                                '(max-width: 300px) 300px',
                                '(max-width: 540px) 540px',
                                '(max-width: 768px) 768px',
                                '(max-width: 1024px) 1024px',
                            )),
                                'srcset' => implode(',', array(
                                    esc_url(wp_get_attachment_image_url($post_thumbnail_id, 'jk-square-size-extra-small')) . ' 300w',
                                    esc_url(wp_get_attachment_image_url($post_thumbnail_id, 'jk-square-size-small')) . ' 540w',
                                    esc_url(wp_get_attachment_image_url($post_thumbnail_id, 'jk-square-size-medium')) . ' 540w',
                                    esc_url(wp_get_attachment_image_url($post_thumbnail_id, 'jk-square-size-large')) . ' 1024w',
                                )),
                                'loading' => 'lazy',
                                'alt' => get_the_title()
                            ), false);

                    else:

                        ?>

                        <img src="<?php echo esc_url(wp_get_attachment_image_url($post_thumbnail_id, 'large')); ?>"
                             alt="<?php echo esc_attr(get_the_title()); ?>">

                    <?php

                    endif;

                    ?>

                </div>

            </div>

        <?php

        endif;

        ?>

    </figure>
</div>
