<?php defined('ABSPATH') || exit;
/*
 * *************************************************************************
 *  * Copyright (C) JK-Studio, Inc - All Rights Reserved
 *  *
 *  * @file        class-jkd-theme-shop.php
 *  * @author      Alexander Poslushnyak
 *  * @website     https://jk-studio-dev.com/
 *  * @date        18/09/2021, 01:10
 *
 */


/**
 * Class JKD_Theme_Shop
 */
class JKD_Theme_Shop extends JKD_Theme
{

    /**
     * JKD_Portfolio constructor.
     */
    public function __construct()
    {

        /* init portfolio */
        $this->init();

    }

    /**
     * init
     */
    public function init()
    {

        /* disable woo select styles / scripts */
        add_action('wp_enqueue_scripts', function () {
            wp_dequeue_style('select2');
            wp_dequeue_script('select2');
            wp_dequeue_script('selectWoo');
        }, 11);

        /* override woo billing checkout fields */
        add_filter('woocommerce_checkout_fields', [$this, 'override_billing_checkout_fields'], 20, 1);

        /* override woo address checkout fields */
        add_filter('woocommerce_default_address_fields', [$this, 'override_default_address_checkout_fields'], 20, 1);

        /* override woo order button text */
        add_filter('woocommerce_order_button_text', [$this, 'override_order_button_text']);

        add_action('woocommerce_shop_loop_item_title', [$this, 'change_products_loop_title'], 10);

        add_action('woocommerce_archive_description', [$this, 'woocommerce_output_all_notices'], 10);

        add_action('woocommerce_after_shop_loop_item_title', [$this, 'woocommerce_template_loop_add_to_cart'], 10);

        add_action('woocommerce_after_shop_loop_item_title', [$this, 'woocommerce_template_loop_rating'], 5);

        remove_action('woocommerce_shop_loop_item_title', 'woocommerce_template_loop_product_title', 10);

        remove_action('woocommerce_archive_description', 'woocommerce_taxonomy_archive_description', 10);

        remove_action('woocommerce_after_shop_loop_item', 'woocommerce_template_loop_add_to_cart', 10);

        remove_action('woocommerce_after_shop_loop_item_title', 'woocommerce_template_loop_rating', 5);

        remove_action('woocommerce_before_shop_loop', 'woocommerce_output_all_notices', 10);

        remove_action('woocommerce_before_shop_loop', 'woocommerce_catalog_ordering', 30);

        remove_action('woocommerce_after_single_product_summary', 'woocommerce_upsell_display', 15);

        remove_action('woocommerce_after_single_product_summary', 'woocommerce_output_related_products', 20);

        remove_action('woocommerce_before_main_content', 'woocommerce_breadcrumb', 20);

        remove_action('woocommerce_before_shop_loop', 'woocommerce_result_count', 20);

    }

    /**
     * @param $fields
     *
     * @return mixed
     */
    public function override_billing_checkout_fields($fields)
    {

        /* billing phone field */
        $fields['billing']['billing_phone']['placeholder'] = esc_html__('Phone (optional)', 'qreatix');

        /* billing email field */
        $fields['billing']['billing_email']['placeholder'] = esc_html__('Email Address', 'qreatix');

        /* return modified fields */
        return $fields;

    }

    /**
     * @param $address_fields
     *
     * @return mixed
     */
    public function override_default_address_checkout_fields($address_fields)
    {

        /* address name field */
        $address_fields['first_name']['placeholder'] = esc_html__('First Name', 'qreatix');

        /* address last name field */
        $address_fields['last_name']['placeholder'] = esc_html__('Last Name', 'qreatix');

        /* address 1 field */
        $address_fields['address_1']['placeholder'] = esc_html__('Address', 'qreatix');

        /* address company field */
        $address_fields['company']['placeholder'] = esc_html__('Company Name (optional)', 'qreatix');

        /* address state field */
        $address_fields['state']['placeholder'] = esc_html__('State / Country', 'qreatix');

        /* address country field */
        $address_fields['country']['placeholder'] = esc_html__('Select Country', 'qreatix');

        /* address postcode field */
        $address_fields['postcode']['placeholder'] = esc_html__('Postcode / Zip', 'qreatix');

        /* address city field */
        $address_fields['city']['placeholder'] = esc_html__('Town / City', 'qreatix');

        /* return modified fields */
        return $address_fields;

    }

    /**
     *
     */
    public function woocommerce_template_loop_add_to_cart()
    {

        woocommerce_template_loop_add_to_cart();

    }


    /**
     *
     */
    public function woocommerce_template_loop_rating()
    {

        global $product;

        if (!empty(wc_get_rating_html($product->get_average_rating()))):

            ?>

            <div class="rating-wrapper">

                <?php wc_get_template('single-product/rating.php'); ?>

            </div>

        <?php

        endif;

    }

    /**
     *
     */
    public function woocommerce_output_all_notices()
    {

        echo '<div class="woocommerce-notices-wrapper">';

        wc_print_notices();

        echo '</div>';

    }

    /**
     *
     */
    public function change_products_loop_title()
    {

        echo '<h5 class="' . esc_attr(apply_filters('woocommerce_product_loop_title_classes', 'woocommerce-loop-product__title')) . '"><a href="' . get_the_permalink() . '" class="multiline-hover">' . get_the_title() . '</a></h5>';

    }

    /**
     * @return string|void
     */
    public function override_order_button_text()
    {

        /* new order button text */
        return esc_html__('Apply Now', 'qreatix');

    }

}
