<?php
/*
 * *************************************************************************
 *  * Copyright (C) JK-Studio, Inc - All Rights Reserved
 *  *
 *  * @file        class-jkd-theme-walker.php
 *  * @author      Alexander Poslushnyak
 *  * @website     https://jk-studio-dev.com/
 *  * @date        18/09/2021, 01:10
 *
 */

/**
 * Class JKD_Theme_Walker
 */
class JKD_Theme_Walker extends Walker
{

    /**
     * @var array
     */
    private $classes;

    /**
     * @return int
     */
    public function getMaxPages()
    {

        return $this->max_pages;

    }

    /**
     * @param int $max_pages
     */
    public function setMaxPages($max_pages)
    {

        $this->max_pages = $max_pages;

    }

    /**
     * @return bool
     */
    public function isHasChildren()
    {

        return $this->has_children;

    }

    /**
     * @param bool $has_children
     */
    public function setHasChildren($has_children)
    {

        $this->has_children = $has_children;

    }

    /**
     * @return array
     */
    public function getClasses()
    {

        return $this->classes;

    }

    /**
     * @param array $classes
     */
    public function setClasses($classes)
    {

        $this->classes = $classes;

    }

    /**
     * @return string
     */
    public function getTreeType()
    {

        return $this->tree_type;

    }

    /**
     * @param string $tree_type
     */
    public function setTreeType($tree_type)
    {

        $this->tree_type = $tree_type;

    }

    /**
     * @return array
     */
    public function getDbFields()
    {

        return $this->db_fields;

    }

    /**
     * @param array $db_fields
     */
    public function setDbFields($db_fields)
    {

        $this->db_fields = $db_fields;

    }

    /**
     * JKD_Walker constructor.
     *
     * @param array $classes
     */
    public function __construct($classes = array())
    {

        $this->classes = $classes;

    }

    /**
     * What the class handles.
     *
     * @since 1.0.0
     * @var string
     *
     * @see Walker::$tree_type
     */
    public $tree_type = array('post_type', 'taxonomy', 'custom');

    /**
     * Database fields to use.
     *
     * @since 1.0.0
     * @var array
     *
     * @see Walker::$db_fields
     */
    public $db_fields = array(
        'parent' => 'menu_item_parent',
        'id' => 'db_id',
    );

    /**
     * Starts the list before the elements are added.
     *
     * @param string $output Used to append additional content (passed by reference).
     * @param int $depth Depth of menu item. Used for padding.
     * @param stdClass $args An object of wp_nav_menu() arguments.
     *
     * @see Walker::start_lvl()
     *
     * @since 1.0.0
     *
     */
    public function start_lvl(&$output, $depth = 0, $args = null)
    {

        if (isset($args->item_spacing) && 'discard' === $args->item_spacing) :

            $t = '';

            $n = '';

        else :

            $t = "\t";

            $n = "\n";

        endif;

        $indent = str_repeat($t, $depth);

        // Default class.
        $classes = array('sub-menu');

        /**
         * Filters the CSS class(es) applied to a menu list element.
         *
         * @param string[] $classes Array of the CSS classes that are applied to the menu `<ul>` element.
         * @param stdClass $args An object of `wp_nav_menu()` arguments.
         * @param int $depth Depth of menu item. Used for padding.
         *
         * @since 4.8.0
         *
         */
        $class_names = join(' ', apply_filters('nav_menu_submenu_css_class', $classes, $args, $depth));

        $class_names = $class_names ? ' class="' . esc_attr($class_names) . '"' : '';

        $output .= "{$n}{$indent}<ul$class_names>{$n}";

    }

    /**
     * Ends the list of after the elements are added.
     *
     * @param string $output Used to append additional content (passed by reference).
     * @param int $depth Depth of menu item. Used for padding.
     * @param stdClass $args An object of wp_nav_menu() arguments.
     *
     * @see Walker::end_lvl()
     *
     * @since 1.0.0
     *
     */
    public function end_lvl(&$output, $depth = 0, $args = null)
    {

        if (isset($args->item_spacing) && 'discard' === $args->item_spacing) :

            $t = '';

            $n = '';

        else :

            $t = "\t";

            $n = "\n";

        endif;

        $indent = str_repeat($t, $depth);

        $output .= "$indent</ul>{$n}";

    }

    /**
     * Starts the element output.
     *
     * @param string $output Used to append additional content (passed by reference).
     * @param WP_Post $item Menu item data object.
     * @param int $depth Depth of menu item. Used for padding.
     * @param stdClass $args An object of wp_nav_menu() arguments.
     * @param int $id Current item ID.
     *
     * @see Walker::start_el()
     *
     * @since 1.0.0
     * @since 4.4.0 The {@see 'nav_menu_item_args'} filter was added.
     *
     */
    public function start_el(&$output, $item, $depth = 0, $args = null, $id = 0)
    {

        if (isset($args->item_spacing) && 'discard' === $args->item_spacing) :

            $t = '';

            $n = '';

        else :

            $t = "\t";

            $n = "\n";

        endif;

        $indent = ($depth) ? str_repeat($t, $depth) : '';

        $item_children_check = false;

        $classes = empty($item->classes) ? array() : (array)$item->classes;

        if ($depth === 0):

            array_push($classes, 'menu-item-1-lvl');

        elseif ($depth === 1):

            array_push($classes, 'menu-item-2-lvl');

        elseif ($depth === 2):

            array_push($classes, 'menu-item-3-lvl');

        endif;

        $classes[] = 'menu-item-' . $item->ID;

        foreach ($classes as $class):

            if ($class === 'menu-item-has-children'):

                $item_children_check = true;

            endif;

        endforeach;

        /**
         * Filters the arguments for a single nav menu item.
         *
         * @param stdClass $args An object of wp_nav_menu() arguments.
         * @param WP_Post $item Menu item data object.
         * @param int $depth Depth of menu item. Used for padding.
         *
         * @since 4.4.0
         *
         */
        $args = apply_filters('nav_menu_item_args', $args, $item, $depth);

        /**
         * Filters the CSS classes applied to a menu item's list item element.
         *
         * @param string[] $classes Array of the CSS classes that are applied to the menu item's `<li>` element.
         * @param WP_Post $item The current menu item.
         * @param stdClass $args An object of wp_nav_menu() arguments.
         * @param int $depth Depth of menu item. Used for padding.
         *
         * @since 1.0.0
         * @since 4.1.0 The `$depth` parameter was added.
         *
         */
        $class_names = join(' ', apply_filters('nav_menu_css_class', array_filter($classes), $item, $args, $depth));

        $class_names = $class_names ? ' class="' . esc_attr($class_names) . '"' : '';

        /**
         * Filters the ID applied to a menu item's list item element.
         *
         * @param string $menu_id The ID that is applied to the menu item's `<li>` element.
         * @param WP_Post $item The current menu item.
         * @param stdClass $args An object of wp_nav_menu() arguments.
         * @param int $depth Depth of menu item. Used for padding.
         *
         * @since 3.0.1
         * @since 4.1.0 The `$depth` parameter was added.
         *
         */
        $id = apply_filters('nav_menu_item_id', 'menu-item-' . $item->ID, $item, $args, $depth);

        $id = $id ? ' id="' . esc_attr($id) . '"' : '';

        $output .= $indent . '<li' . $id . $class_names . '>';

        $atts = array();

        $atts['title'] = !empty($item->attr_title) ? $item->attr_title : '';

        $atts['target'] = !empty($item->target) ? $item->target : '';

        if ('_blank' === $item->target && empty($item->xfn)) :

            $atts['rel'] = 'noopener noreferrer';

        else :

            $atts['rel'] = $item->xfn;

        endif;

        $atts['href'] = !empty($item->url) ? $item->url : '';

        $atts['aria-current'] = $item->current ? 'page' : '';

        /**
         * Filters the HTML attributes applied to a menu item's anchor element.
         *
         * @param array $atts {
         *     The HTML attributes applied to the menu item's `<a>` element, empty strings are ignored.
         *
         * @type string $title Title attribute.
         * @type string $target Target attribute.
         * @type string $rel The rel attribute.
         * @type string $href The href attribute.
         * @type string $aria_current The aria-current attribute.
         * }
         *
         * @param WP_Post $item The current menu item.
         * @param stdClass $args An object of wp_nav_menu() arguments.
         * @param int $depth Depth of menu item. Used for padding.
         *
         * @since 3.6.0
         * @since 4.1.0 The `$depth` parameter was added.
         *
         */
        $atts = apply_filters('nav_menu_link_attributes', $atts, $item, $args, $depth);

        $attributes = '';

        foreach ($atts as $attr => $value) :

            if (is_scalar($value) && '' !== $value && false !== $value) :

                $value = ('href' === $attr) ? esc_url($value) : esc_attr($value);

                $attributes .= ' ' . $attr . '="' . $value . '"';

            endif;

        endforeach;

        /** This filter is documented in wp-includes/post-template.php */
        $title = apply_filters('the_title', $item->title, $item->ID);

        /**
         * Filters a menu item's title.
         *
         * @param string $title The menu item's title.
         * @param WP_Post $item The current menu item.
         * @param stdClass $args An object of wp_nav_menu() arguments.
         * @param int $depth Depth of menu item. Used for padding.
         *
         * @since 4.4.0
         *
         */
        $title = apply_filters('nav_menu_item_title', $title, $item, $args, $depth);

        $item_output = $args->before;

        $item_output .= '<a' . $attributes . '>';

        $item_output .= $args->link_before . $title . $args->link_after;

        if ($item_children_check):

            $item_output .= '<span class="menu-item-icon"><i class="ri-arrow-down-s-line"></i></span>';

        endif;

        $item_output .= '</a>';

        $item_output .= $args->after;

        /**
         * Filters a menu item's starting output.
         *
         * The menu item's starting output only includes `$args->before`, the opening `<a>`,
         * the menu item's title, the closing `</a>`, and `$args->after`. Currently, there is
         * no filter for modifying the opening and closing `<li>` for a menu item.
         *
         * @param string $item_output The menu item's starting HTML output.
         * @param WP_Post $item Menu item data object.
         * @param int $depth Depth of menu item. Used for padding.
         * @param stdClass $args An object of wp_nav_menu() arguments.
         *
         * @since 1.0.0
         *
         */
        $output .= apply_filters('walker_nav_menu_start_el', $item_output, $item, $depth, $args);

    }

    /**
     * Ends the element output, if needed.
     *
     * @param string $output Used to append additional content (passed by reference).
     * @param WP_Post $item Page data object. Not used.
     * @param int $depth Depth of page. Not Used.
     * @param stdClass $args An object of wp_nav_menu() arguments.
     *
     * @since 1.0.0
     *
     * @see Walker::end_el()
     *
     */
    public function end_el(&$output, $item, $depth = 0, $args = null)
    {

        if (isset($args->item_spacing) && 'discard' === $args->item_spacing) :

            $t = '';

            $n = '';

        else :

            $t = "\t";

            $n = "\n";

        endif;

        $output .= "</li>{$n}";

    }

}
