<?php defined('ABSPATH') || exit;
/*
 * *************************************************************************
 *  * Copyright (C) JK-Studio, Inc - All Rights Reserved
 *  *
 *  * @file        class-jkd-theme.php
 *  * @author      Alexander Poslushnyak
 *  * @website     https://jk-studio-dev.com/
 *  * @date        18/09/2021, 01:10
 *
 */

/* theme activation trigger */
$theme_activation = get_option('jkdevstudioactivation');

/* check theme activation */
if ($theme_activation):

    /* include class-tgm-plugin-activation */
    require_once('class-tgm-plugin-activation.php');

else:

    /* not activated notice */

    /**
     *
     */
    /**
     *
     */
    function theme_not_activated_notice()
    {

        /* class */
        $class = 'notice notice-warning';

        /* message */
        $message = __('Warning! Your theme is not activated! To activate, go to:', 'qreatix');

        /* alert */
        printf('<div class="%1$s"><p>%2$s <a href="' . esc_url(admin_url() . 'adphp?page=theme-dashboard') . '">' . esc_html__('License', 'qreatix') . '</a></p></div>', esc_attr($class), esc_html($message));

    }

    /* admin_notices action */
    add_action('admin_notices', 'theme_not_activated_notice');

endif;

if (!class_exists('JKD_Core')):

    /* include main walker theme class */
    require_once(get_template_directory() . '/class-jkd-theme-walker.php');

    /* include theme shop class */
    require_once(get_template_directory() . '/class-jkd-theme-shop.php');

endif;

/**
 * Class JKD_Theme
 */
class JKD_Theme
{

    /**
     * @var mixed|string
     */
    public static $id = '';

    /**
     * @var mixed|string
     */
    public static $version = '';

    /**
     * @var string
     */
    public static $name = '';

    /**
     * @var string
     */
    public static $demo = '';

    /**
     * @var string
     */
    protected $update_repo_url = '';

    /**
     * @var string
     */
    protected $update_local_path = '';

    /**
     * @var string
     */
    protected $update_repo_slug = '';

    /**
     * @var string
     */
    protected $assets_url = '';

    /**
     * @return string
     */
    public function getAssetsUrl()
    {

        /* return assets url */
        return $this->assets_url;

    }

    /**
     * @param string $assets_url
     */
    public function setAssetsUrl($assets_url)
    {

        /* set assets url */
        $this->assets_url = $assets_url;

    }

    /**
     * @return string
     */
    public function getUpdateRepoUrl()
    {

        /* return update  repo url */
        return $this->update_repo_url;

    }

    /**
     * @param string $update_repo_url
     */
    public function setUpdateRepoUrl($update_repo_url)
    {

        /* set update  repo url */
        $this->update_repo_url = $update_repo_url;

    }

    /**
     * @return string
     */
    public function getUpdateLocalPath()
    {

        /* return update local update path */
        return $this->update_local_path;

    }

    /**
     * @param string $update_local_path
     */
    public function setUpdateLocalPath($update_local_path)
    {

        /* set update local update path */
        $this->update_local_path = $update_local_path;

    }

    /**
     * @return string
     */
    public function getUpdateRepoSlug()
    {

        /* return update repo slug */
        return $this->update_repo_slug;

    }

    /**
     * @param string $update_repo_slug
     */
    public function setUpdateRepoSlug($update_repo_slug)
    {

        /* set update repo slug */
        $this->update_repo_slug = $update_repo_slug;

    }

    /**
     * @return mixed|string
     */
    public static function getId()
    {

        /* return id */
        return self::$id;

    }

    /**
     * @param mixed|string $id
     */
    public static function setId($id)
    {

        /* set id */
        self::$id = $id;

    }

    /**
     * @return mixed|string
     */
    public static function getVersion()
    {

        /* return version */
        return self::$version;

    }

    /**
     * @param mixed|string $version
     */
    public static function setVersion($version)
    {

        /* set version */
        self::$version = $version;

    }

    /**
     * @param mixed|string $name
     */
    public static function setName($name)
    {

        /* set name */
        self::$name = $name;

    }

    /**
     * @param mixed|string $demo
     */
    public static function setDemo($demo)
    {

        /* set name */
        self::$demo = $demo;

    }

    /**
     * @return string
     */
    public static function getName()
    {

        /* return name */
        return self::$name;

    }

    /**
     * JKD_Theme constructor.
     *
     * @param $args
     */
    public function __construct($args)
    {

        /* added custom upload extensions (mime types) */
        add_filter('mime_types', [$this, 'custom_upload_extensions']);

        add_filter('upload_mimes', [$this, 'custom_upload_extensions']);

        /* setup id */
        if (!empty($args['id'])):

            /* new value */
            $this->setId($args['id']);

        endif;

        /* setup repo slug */
        if (!empty($args['update_repo_slug'])):

            /* new value */
            $this->setUpdateRepoSlug($args['update_repo_slug']);

        endif;

        /* setup local update path */
        if (!empty($args['update_local_path'])):

            /* new value */
            $this->setUpdateLocalPath($args['update_local_path']);

        endif;

        /* setup repo url */
        if (!empty($args['update_repo_url'])):

            /* new value */
            $this->setUpdateRepoUrl($args['update_repo_url']);

        endif;

        /* setup assets url */
        if (!empty($args['assets_url'])):

            /* new value */
            $this->setAssetsUrl($args['assets_url']);

        endif;

        /* setup version of theme */
        if (!empty($args['version'])):

            /* new value */
            $this->setVersion($args['version']);

        else:

            /* default value */
            $this->setVersion('1.0');

        endif;

        /* setup theme name */
        if (!empty($args['name'])):

            /* new value */
            $this->setName($args['name']);

        else:

            /* default value */
            $this->setName(esc_html('Qreatix'));

        endif;

        /* setup theme name */
        if (!empty($args['demo'])):

            /* new value */
            $this->setDemo($args['demo']);

        else:

            /* default value */
            $this->setDemo(esc_url('https://qreatix-theme.jk-studio-dev.com'));

        endif;

        /* init theme */
        $this->init_theme();

    }

    /**
     * init theme
     */
    protected function init_theme()
    {

        /* init textdomain */
        add_action('init', [$this, 'i18n']);

        /* init sidebar area */
        add_action('widgets_init', [$this, 'init_sidebar_area']);

        /* init navigation area */
        add_action('after_setup_theme', [$this, 'init_navigation_area']);

        /* theme setup values */
        add_action('after_setup_theme', [$this, 'theme_setup']);

        /* enqueue lib styles */
        add_action('wp_enqueue_scripts', [$this, 'enqueue_styles_lib']);

        /* enqueue theme styles */
        add_action('wp_enqueue_scripts', [$this, 'enqueue_styles_theme']);

        /* enqueue lib scripts */
        add_action('wp_enqueue_scripts', [$this, 'enqueue_scripts_lib']);

        /* enqueue theme scripts */
        add_action('wp_enqueue_scripts', [$this, 'enqueue_scripts_theme']);

        /* enqueue inline theme styles */
        add_action('wp_enqueue_scripts', [$this, 'inline_enqueue_styles']);

        /* enqueue theme admin styles */
        add_action('admin_head', [$this, 'enqueue_admin_styles']);

        /* enqueue theme admin scripts */
        add_action('admin_head', [$this, 'enqueue_admin_scripts']);

        /* dns prefetch

        Tells the browser to download and cache a resource
        (like a script or a stylesheet) as soon as possible

         */
        add_action('admin_head', [$this, 'dns_prefetch']);

        /* dns preconnect

        Informs the browser that your page intends to
        establish a connection to another origin, and
        that you'd like the process to start as soon as possible.

         */
        add_action('admin_head', [$this, 'dns_preconnect']);

        /* add pingback link to <head> */
        add_action('wp_head', [$this, 'pingback_header']);

        /* remove sitename from the document title */
        add_filter('document_title_parts', [$this, 'remove_sitename_from_title'], 10, 1);

        /* Update comment form fields */
        add_filter('comment_form_default_fields', [$this, 'comment_form_default_fields']);

        /* Update comment form textarea */
        add_filter('comment_form_field_comment', [$this, 'comment_form_field_comment']);

        /* change default comment template */
        add_filter('wp_list_comments_args', function ($args) {

            /* check if is singular OR page (if main class disabled) */
            if (is_singular('post') || is_page() || function_exists('tribe_is_not_min_php_version') && tribe_is_event_query()):

                /* rewrite comments callback */
                $args['callback'] = function ($comment, $depth, $args) {

                    /* custom comment template */
                    $this->comment_template($comment, $depth, $args);

                };

            endif;

            /* return modify args */
            return $args;

        });

        /* init theme dashboard */
        $this->init_theme_dashboard();

        /* init theme modules */
        $this->init_theme_modules();

    }

    /**
     *
     */
    public function init_theme_modules()
    {

        /* theme activation trigger

        It is auto-updated and checked on our server

         */
        $theme_activation = get_option('jkdevstudioactivation');

        /* Simple theme activation check */
        if ($theme_activation):

            /* init theme updates */
            add_action('init', [$this, 'init_theme_updates'], 0);

            /* check if exists ocdi */
            if (class_exists('OCDI_Plugin')):

                /* disable ocdi branding */
                add_filter('pt-ocdi/disable_pt_branding', '__return_true');

                /* ocdi after import */
                add_action('pt-ocdi/after_import', [$this, 'ocdi_after_import_setup']);

                /* ocdi import files */
                add_filter('pt-ocdi/import_files', [$this, 'ocdi_import_files']);

                add_filter('ocdi/plugin_page_setup', [$this, 'ocdi_plugin_page_setup']);

            endif;

            /* check if exists tgma */
            if (class_exists('TGM_Plugin_Activation')):

                /* tgm required plugins */
                add_action('tgmpa_register', [$this, 'register_required_plugins']);

            endif;

            if (!class_exists('JKD_Core')):

                new JKD_Theme_Shop();

            endif;

        endif;

    }

    /**
     * pingback header
     */
    public function pingback_header()
    {

        /* check is singular && pings open */
        if (is_singular() && pings_open()) :

            ?>

            <!-- pingback url -->
            <link rel="pingback" href="<?php echo esc_url(get_bloginfo('pingback_url')); ?>">

        <?php

        endif;

    }

    /**
     * init theme updates
     */
    public function init_theme_updates()
    {

        /* check if auto-update checker exists */
        if (class_exists('Puc_v4_Factory')):

            /* builder auto update config */
            Puc_v4_Factory::buildUpdateChecker(
            /* update url */
                $this->getUpdateRepoUrl(),
                /* local path */
                $this->getUpdateLocalPath(),
                /* repo slug */
                $this->getUpdateRepoSlug()
            );

        endif;

    }

    /**
     * init theme dashboard
     */
    public function init_theme_dashboard()
    {

        /* check if JKD_Theme_Dashboard exists */
        if (class_exists('JKD_Theme_Dashboard')):

            /* JKD_Theme_Dashboard instance */
            new JKD_Theme_Dashboard(array(
                // Dashboard title
                'page_title' => esc_html('Qreatix'),
                // Admin panel title
                'menu_title' => esc_html('Qreatix Dashboard'),
                // capability for editing
                'capability' => 'edit_theme_options',
                // Admin panel menu-slug
                'menu_slug' => 'theme-dashboard',
                // Icon url
                'icon_url' => esc_url(get_template_directory_uri() . '/assets/img/theme-logo-icon.svg'),
                // Admin panel position
                'position' => 49,
                /* support url */
                'support_url' => esc_url('https://themeforest.net/item/qreatix-interactive-portfolio-wordpress-theme/31728964/support'),
                /* docs url */
                'docs_url' => esc_url('https://jk-studio-dev.com/docs/qreatix-wp/'),
                /* changelog url */
                'changelog_url' => esc_url('https://jk-studio-dev.com/docs/qreatix-wp/changelog/'),
                /* feature requests url */
                'feature_requests_url' => esc_url('https://jk-studio-dev.com/feature-request/'),
            ));

        endif;

    }

    /**
     * register required theme plugins
     */
    public function register_required_plugins()
    {

        /* plugins array */
        $plugins = array(
            /* Qreatix Core Plugin */
            array(
                'name' => 'Qreatix Core Plugin',
                'slug' => 'jkd-wp-qreatix-core',
                'source' => $this->assets_url . '/plugin/jkd-wp-qreatix-core-1.5.zip',
                'required' => true,
                'version' => 1.5,
                'force_activation' => false,
                'force_deactivation' => false,
            ),
            /* Advanced Custom Fields PRO */
            array(
                'name' => 'Advanced Custom Fields PRO',
                'slug' => 'advanced-custom-fields-pro',
                'source' => $this->assets_url . '/extra/advanced-custom-fields-pro.zip',
                'required' => true,
                'version' => 1.0,
                'force_activation' => false,
                'force_deactivation' => false,
            ),
            /* Advanced Custom Fields PRO */
            array(
                'name' => 'Slider Revolution',
                'slug' => 'revslider',
                'source' => $this->assets_url . '/extra/revslider.zip',
                'required' => false,
                'version' => 1.0,
                'force_activation' => false,
                'force_deactivation' => false,
            ),
            /* Kirki Customizer Framework */
            array(
                'name' => 'Kirki',
                'slug' => 'kirki',
                'required' => true,
            ),
            /* Elementor */
            array(
                'name' => 'Elementor',
                'slug' => 'elementor',
                'required' => false,
            ),
            /* Woocommerce */
            array(
                'name' => 'WooCommerce',
                'slug' => 'woocommerce',
                'required' => false,
            ),
            /* The Events Calendar */
            array(
                'name' => 'The Events Calendar',
                'slug' => 'the-events-calendar',
                'required' => false,
            ),
            /* Event Tickets */
            array(
                'name' => 'Event Tickets',
                'slug' => 'event-tickets',
                'required' => false,
            ),
            /* Contact Form 7 */
            array(
                'name' => 'Contact Form 7',
                'slug' => 'contact-form-7',
                'required' => false,
            ),
            /* Mailchimp for WordPress */
            array(
                'name' => 'Mailchimp for WordPress',
                'slug' => 'mailchimp-for-wp',
                'required' => false,
            ),
            /* OCDI */
            array(
                'name' => 'One Click Demo Import',
                'slug' => 'one-click-demo-import',
                'required' => false,
            ),
            /* PW WooCommerce Gift Cards */
            array(
                'name' => 'PW WooCommerce Gift Cards',
                'slug' => 'pw-woocommerce-gift-cards',
                'required' => false,
            ),
            /* TI WooCommerce Wishlist */
            array(
                'name' => 'TI WooCommerce Wishlist',
                'slug' => 'ti-woocommerce-wishlist',
                'required' => false,
            ),
            /* Variation Swatches for WooCommerce */
            array(
                'name' => 'Variation Swatches for WooCommerce',
                'slug' => 'woo-variation-swatches',
                'required' => false,
            ),
            /* WOOF - WooCommerce Products Filter */
            array(
                'name' => 'WOOF - WooCommerce Products Filter',
                'slug' => 'woocommerce-products-filter',
                'required' => false,
            ),
        );

        /* tgm config */
        $config = array(
            'id' => 'qreatix',
            'has_notices' => true,
            'dismissable' => true,
            'is_automatic' => true,
        );

        /* init tgmpa */
        tgmpa($plugins, $config);

    }

    /**
     * @return array
     */
    public function ocdi_import_files()
    {

        /* return main demo */
        return array(

            /* (#0) main demo */
            array(
                /* demo name */
                'import_file_name' => esc_html('Qreatix'),
                /* demo XML (content) */
                'import_file_url' => self::getAssetsUrl() . 'demo/demo.xml',
                /* demo dat (customizer settings) */
                'import_customizer_file_url' => self::getAssetsUrl() . 'demo/demo.dat',
                /* import widgets */
                'import_widget_file_url' => self::getAssetsUrl() . 'demo/demo.wie',
                /* import preview */
                //'import_preview_image_url' => trailingslashit(self::getAssetsUrl()) . 'demo/demo.jpg',
                /* preview */
                'preview_url' => trailingslashit(self::getAssetsUrl()) . 'demo/demo.jpg',
            ),

        );

    }

    /**
     * @param $default_settings
     *
     * @return mixed
     */
    public function ocdi_plugin_page_setup($default_settings)
    {

        $default_settings['parent_slug'] = 'theme-dashboard';

        return $default_settings;

    }


    /**
     * @param $selected_import
     */
    public function ocdi_after_import_setup($selected_import)
    {

        /* define global wp rewrite */
        global $wp_rewrite;

        /* get navigation menu */
        $navigation_menu = get_term_by('name', 'Menu 1', 'nav_menu');

        /* get error menu */
        $error_menu = get_term_by('name', 'Menu 2', 'nav_menu');

        /* update rewrite rules to false */
        update_option("rewrite_rules", false);

        /* get front page id */
        $front_page_id = get_page_by_title('Tiles Grid');

        /* set menu navigation */
        set_theme_mod('nav_menu_locations',
            array(
                'primary_menu' => $navigation_menu->term_id,
            )
        );

        /* set error navigation */
        set_theme_mod('nav_menu_locations',
            array(
                'error_menu' => $error_menu->term_id,
            )
        );

        /* set permalink structure */
        $wp_rewrite->set_permalink_structure('/%postname%/');

        /* flush permalinks */
        $wp_rewrite->flush_rules(true);

        /* set front page */
        update_option('page_on_front', $front_page_id->ID, false);

    }

    /**
     * @param $existing_mimes
     *
     * @return mixed
     */
    public function custom_upload_extensions($existing_mimes)
    {

        /*

        added dat to current mimes array
        used for .dat customizer import (Kirki settings)

        */
        $existing_mimes['dat'] = 'text/plain';

        /*

        added wie to current mimes array
        used for .wie widgets import

        */
        $existing_mimes['wie'] = 'text/plain';

        /* return mimes with new ones */
        return $existing_mimes;


    }

    /**
     * init theme translation (i18n)
     */
    public function i18n()
    {

        /* register theme text domain */
        load_theme_textdomain('qreatix', get_template_directory() . '/lang');

    }

    /**
     * enqueue theme admin scripts
     */
    public function enqueue_admin_scripts()
    {

        /* check if admin scripts exists */
        if (!wp_script_is('jkd-admin')):

            /* init global wp */
            global $wp;

            /* enqueue admin scripts */
            wp_enqueue_script('jkd-admin', get_template_directory_uri() . '/assets/js/theme/admin.js', array('jquery', 'imagesloaded'), self::$version, true);

            /* localize jkd_ajax object */
            wp_localize_script('jkd-admin', 'jkd_ajax', array(
                'ajaxurl' => admin_url() . '/admin-ajax.php'
            ));

            /*
             *
             * FOR REMOTE CONNECTION AND THEME ACTIVATION
             *
             * */

            /* localize license_info object */
            wp_localize_script('jkd-admin', 'license_info', array(
                'item_id' => self::$id,
                'hostname' => esc_url(home_url($wp->request))
            ));

        endif;

    }

    /**
     * enqueue theme admin styles
     */
    public function enqueue_admin_styles()
    {

        /* check if default-fonts styles exists */
        if (!wp_style_is('jkd-theme-default-fonts') && !class_exists('JKD_Core')):

            /* enqueue default-fonts styles */
            wp_enqueue_style('jkd-theme-default-fonts', get_template_directory_uri() . '/assets/css/theme/default-fonts.css');

        endif;

        /* check if remix icons styles exists */
        if (!wp_style_is('jkd-remix-icons')):

            /* enqueue remix icons styles */
            wp_enqueue_style('jkd-remix-icons', get_template_directory_uri() . '/assets/css/lib/remixicon.min.css');

        endif;

        /* check if admin styles exists */
        if (!wp_style_is('jkd-admin')):

            /* enqueue admin styles */
            wp_enqueue_style('jkd-admin', get_template_directory_uri() . '/assets/css/theme/admin.css');

        endif;

    }

    /**
     * enqueue lib styles
     */
    public function enqueue_styles_lib()
    {

        /* check if remix icons styles exists */
        if (!wp_style_is('jkd-remix-icons')):

            /* enqueue remix icons styles */
            wp_enqueue_style('jkd-remix-icons', get_template_directory_uri() . '/assets/css/lib/remixicon.min.css');

        endif;

        /* check if woocommerce styles exists */
        if (!wp_style_is('swiper-slider')):

            /* enqueue woocommerce styles */
            wp_register_style('swiper-slider', get_template_directory_uri() . '/assets/css/lib/swiper.min.css');

            wp_deregister_style('swiper');

        endif;

    }

    /**
     * enqueue theme styles
     */
    public function enqueue_styles_theme()
    {

        /* get rtl global var from the customizer */
        $rtl = get_theme_mod('general-rtl-toggle', false);

        /* assets suffixes array */
        $suffix = array();

        /* $_GET query for the rtl */
        if (!empty($_GET['rtl'])):

            /* get rtl var from the $_GET query */
            $rtl = $_GET['rtl'];

        endif;

        /* if rtl setting is true */
        if ($rtl):

            /* added .rtl to assets suffixes */
            array_push($suffix, '.rtl');

        endif;

        /* implode all suffixes */
        $suffix = implode('', $suffix);

        /* check if default-fonts styles exists */
        if (!wp_style_is('jkd-theme-default-fonts') && !class_exists('JKD_Core')):

            /* enqueue default-fonts styles */
            wp_enqueue_style('jkd-theme-default-fonts', get_template_directory_uri() . '/assets/css/theme/default-fonts.css');

        endif;

        /* check if sidebar styles exists */
        if (!wp_style_is('jkd-theme-sidebar')):

            /* enqueue sidebar styles */
            wp_enqueue_style('jkd-theme-sidebar', get_template_directory_uri() . '/assets/css/theme/sidebar' . $suffix . '.css');

        endif;

        /* check if default styles exists */
        if (!wp_style_is('jkd-theme-default') && !class_exists('JKD_Core')):

            /* enqueue default styles */
            wp_enqueue_style('jkd-theme-default', get_template_directory_uri() . '/assets/css/theme/default' . $suffix . '.css');

        endif;

        /* check if woocommerce styles exists */
        if (!wp_style_is('jkd-theme-woocommerce', 'registered')):

            /* enqueue woocommerce styles */
            wp_register_style('jkd-theme-woocommerce', get_template_directory_uri() . '/assets/css/theme/woocommerce' . $suffix . '.css');

        endif;

        /* check if main styles exists */
        if (!wp_style_is('jkd-theme-main')):

            /* enqueue main styles */
            wp_enqueue_style('jkd-theme-main', get_template_directory_uri() . '/assets/css/theme/main' . $suffix . '.css');

        endif;

    }

    /**
     * enqueue theme scripts
     */
    public function enqueue_scripts_lib()
    {

        /* check if easyzoom scripts exists */
        if (!wp_script_is('easyzoom')):

            /* enqueue easyzoom scripts */
            wp_register_script('easyzoom', get_template_directory_uri() . '/assets/js/lib/easyzoom.min.js', array('jquery', 'imagesloaded'),
                self::$version, true);

        endif;

        /* check if gsap scripts exists */
        if (!wp_script_is('gsap')):

            /* enqueue gsap scripts */
            wp_enqueue_script('gsap', get_template_directory_uri() . '/assets/js/lib/gsap.min.js', array('jquery', 'imagesloaded'),
                self::$version, true);

        endif;

        if (!class_exists('JKD_Core')):

            /* check if swiper scripts exists */
            if (!wp_script_is('swiper')):

                /* enqueue swiper scripts */
                wp_register_script('swiper', get_template_directory_uri() . '/assets/js/lib/swiper.min.js', array('jquery', 'imagesloaded'),
                    self::$version, true);

            endif;

        endif;

    }

    /**
     * enqueue theme scripts
     */
    public function enqueue_scripts_theme()
    {

        /* check if singular || comments_open || thread_comments option === true */
        if (is_singular() && comments_open() && get_option('thread_comments')) :

            /* enqueue comment-reply script */
            wp_enqueue_script('comment-reply');

        endif;

        /* check if woocommerce scripts exists */
        if (!wp_script_is('jkd-theme-woocommerce', 'registered')):

            /* enqueue woocommerce scripts */
            wp_register_script('jkd-theme-woocommerce', get_template_directory_uri() . '/assets/js/theme/woocommerce.js', array('jquery', 'imagesloaded'),
                self::$version, true);

        endif;

        /* check if main scripts exists */
        if (!wp_script_is('jkd-theme-main') && !class_exists('JKD_Core')):

            /* enqueue main scripts */
            wp_enqueue_script('jkd-theme-main', get_template_directory_uri() . '/assets/js/theme/main.js', array('jquery', 'imagesloaded'),
                self::$version, true);

        endif;

    }

    /**
     *
     */
    public function inline_enqueue_styles()
    {

        $offset = get_theme_mod('shop-items-offset', esc_attr(15));

        if (!empty($_GET['offset'])):

            $offset = $_GET['offset'];

        endif;

        $inline_css = "
        
        .shop-loop-wrapper .products{
           margin: -{$offset}px!important;
        }
                
        ";

        wp_add_inline_style('jkd-theme-main', $inline_css);

    }

    /**
     * init navigation area
     */
    public function init_navigation_area()
    {

        /* register primary nav menu (navigation area) */
        register_nav_menus(array(
            'primary_menu' => esc_html__('Navigation Menu', 'qreatix'),
        ));

        /* check if core plugin exists */
        if (class_exists('JKD_Core')):

            /* register error nav menu (404 page area) */
            register_nav_menus(array(
                'error_menu' => esc_html__('Error Menu', 'qreatix'),
            ));

        endif;

    }

    /**
     * init sidebar area
     */
    public function init_sidebar_area()
    {

        /* check if core class and Woo exists */
        if (class_exists('JKD_Core') && class_exists('WooCommerce')):

            /* register shop sidebar */
            register_sidebar(array(
                'name' => esc_html__('Shop filters sidebar', 'qreatix'),
                'id' => 'shop-filters-sidebar',
                'description' => esc_html__('Shop filters sidebar', 'qreatix'),
                'before_widget' => '<div id="%1$s" class="sidebar-widget %2$s" >',
                'after_widget' => '</div>',
                'before_title' => '<h6 class="widget-title">',
                'after_title' => '</h6>',
            ));

        endif;

        /* register default blog sidebar */
        register_sidebar(array(
            'name' => esc_html__('Blog sidebar', 'qreatix'),
            'id' => 'blog-sidebar',
            'description' => esc_html__('Blog sidebar', 'qreatix'),
            'before_widget' => '<div class="overflow-wrapper sidebar-widget-wrapper"><div id="%1$s" class="sidebar-widget %2$s" >',
            'after_widget' => '</div></div>',
            'before_title' => '<h6 class="widget-title">',
            'after_title' => '</h6>',
        ));

    }

    /**
     * theme setup
     */
    public function theme_setup()
    {

        /* add editor styles */
        add_editor_style();

        /* add automatic-feed-links support */
        add_theme_support('automatic-feed-links');

        /* add post-thumbnails support */
        add_theme_support('post-thumbnails');

        /* add html5 support */
        add_theme_support('html5', array('comment-list', 'comment-form', 'search-form', 'gallery', 'caption'));

        /* add customize-selective-refresh-widgets support */
        add_theme_support('customize-selective-refresh-widgets');

        /* add post-formats support */
        add_theme_support('post-formats', array('video', 'gallery', 'quote', 'aside', 'image', 'link', 'audio'));

        /* add title-tag support */
        add_theme_support("title-tag");

        /* add editor-styles support */
        add_theme_support('editor-styles');

        /* check if WooCommerce exists */
        if (class_exists('WooCommerce')):

            /* add woocommerce support */
            add_theme_support('woocommerce');

        endif;

        /* check if content width exists */
        if (!isset($content_width)):

            /* default content width */
            $content_width = 1200;

        endif;

    }

    /**
     * @param $fields
     *
     * @return mixed
     */
    public function comment_form_default_fields($fields)
    {

        /* check if is single post */
        if (is_singular('post') || is_page() || function_exists('tribe_is_not_min_php_version') && tribe_is_event_query()):

            /* get current commenter */
            $commenter = wp_get_current_commenter();

            /* get requite name email */
            $req = get_option('require_name_email');

            /* set aria req */
            $aria_req = $req ? "aria-required='true'" : '';

            /* set new author field */
            $fields['author'] = '<div class="input-wrapper"><p class="comment-form-author input-field-wrapper">
            <input id="author" 
            class="input-field jkd-input"
            name="author" 
            type="text" 
            placeholder="' . esc_attr__("Jonathan Doe", "qreatix") . '" 
            value="' . esc_attr($commenter['comment_author']) . '" 
            size="30" ' . $aria_req . ' /></p>';

            /* set new email field */
            $fields['email'] = '<p class="comment-form-email input-field-wrapper">
            <input id="email" 
            class="input-field jkd-input"
            name="email" 
            type="email" 
            placeholder="' . esc_attr("example@domain.com") . '" 
            value="' . esc_attr($commenter['comment_author_email']) . '" 
            size="30" ' . $aria_req . ' /></p>';

            /* set new website url field */
            $fields['url'] = '<p class="comment-form-url input-field-wrapper">
            <input id="url" 
            class="input-field jkd-input"
            name="url" 
            type="url"  
            placeholder="' . esc_attr("http://example.com") . '" 
            value="' . esc_attr($commenter['comment_author_url']) . '" 
            size="30" /></p></div>';

        endif;

        /* return modified fields */
        return $fields;

    }

    /**
     * @param $comment_field
     *
     * @return string
     */
    public function comment_form_field_comment($comment_field)
    {

        /* check if is single post */
        if (is_singular('post') || is_page() || function_exists('tribe_is_not_min_php_version') && tribe_is_event_query()):

            /* set new comment field */
            $comment_field = '<div class="comment-form-textarea">
            <textarea required id="comment" 
            name="comment" 
            class="jkd-textarea"
            placeholder="' . esc_attr__("Comment", "qreatix") . '" 
            aria-required="true"></textarea></div>';

        endif;

        /* return modified field */
        return $comment_field;

    }

    /**
     * @param $comment
     * @param bool $depth
     * @param bool $args
     */
    public static function comment_template($comment, $depth = false, $args = false)
    {

        /* check if comment exists */
        if ($comment):

            ?>

            <!-- comment -->
            <li id="comment-<?php comment_ID(); ?>" <?php comment_class(empty($args['has_children']) ? '' : 'parent', $comment); ?>>

                <!-- comment body -->
                <div class="comment-body">

                    <!-- author avatar -->
                    <div class="author-avatar">

                        <?php

                        /* check if avatar size is empty */
                        if (empty($args['avatar_size'])):

                            /* avatar size */
                            $avatar_size = 100;

                        else:

                            /* avatar size */
                            $avatar_size = $args['avatar_size'];

                        endif;

                        /* output avatar */
                        echo get_avatar($comment, $avatar_size);

                        /* unset avatar size */
                        unset($avatar_size);

                        ?>

                    </div>

                    <!-- comment content -->
                    <div class="comment-content">

                        <div class="name-wrapper">

                            <!-- author name -->
                            <h6 class="author-name">

                                <?php

                                /* comment author link */
                                comment_author_link();

                                ?>

                            </h6>

                            <!-- date wrapper -->
                            <div class="date-wrapper">

                                <!-- date -->
                                <p class="date">

                                    <?php

                                    /* output comment date */
                                    printf(esc_html('%1$s at %2$s'), get_comment_date(), get_comment_time());

                                    ?>

                                </p>

                                <?php

                                /* output edit comment link */
                                edit_comment_link(esc_html__('Edit', 'qreatix'),
                                    '<p class="edit-button"><i class="far fa-edit"></i>',
                                    '</p>');

                                ?>

                            </div>

                        </div>

                        <!-- comment text -->
                        <div class="comment-text entry-content">

                            <?php

                            /* output comment text */
                            comment_text();

                            /* output comment reply link */
                            comment_reply_link(array(
                                'reply_text' => esc_html__('Reply', 'qreatix'),
                                'depth' => 5,
                                'max_depth' => 10,
                                'before' => '<span class="reply-link-wrapper">',
                                'after' => '</span>'
                            ), $comment);

                            ?>

                        </div>

                        <?php if ('0' == $comment->comment_approved) : ?>

                            <!-- comment awaiting moderation -->
                            <p class="comment-awaiting-moderation">

                                <?php echo esc_html__('Your comment is awaiting moderation.', 'qreatix'); ?>

                            </p>

                        <?php endif; ?>

                    </div>

                </div>

            </li>

        <?php

        endif;

    }

    /**
     * @param $str
     *
     * @return mixed
     */
    public static function check_for_empty($str)
    {

        /* check if string is empty */
        if (!empty($str)):

            /* return string */
            return $str;

        endif;

    }

    /**
     * @param $title
     *
     * @return mixed
     */
    public function remove_sitename_from_title($title)
    {

        /* remove sitename from the array */
        unset($title['site']);

        /* return title */
        return $title;

    }

    /**
     * dns prefetch handler
     */
    public function dns_prefetch()
    {

        ?>

        <!-- Prefetch google fonts -->
        <link rel="dns-prefetch" href="//fonts.googleapis.com/">

        <!-- Prefetch google analytics -->
        <link rel="dns-prefetch" href="//www.google-analytics.com">

        <?php

    }

    /**
     * dns preconnect handler
     */
    public function dns_preconnect()
    {

        ?>

        <!-- Preconnect google fonts -->
        <link rel="preconnect" href="//fonts.googleapis.com/">

        <!-- Preconnect google analytics -->
        <link rel="preconnect" href="//www.google-analytics.com">

        <?php

    }

}
