<?php
/*
 * *************************************************************************
 *  * Copyright (C) JK-Studio, Inc - All Rights Reserved
 *  *
 *  * @file        archive-product.php
 *  * @author      Alexander Poslushnyak
 *  * @website     https://jk-studio-dev.com/
 *  * @date        18/09/2021, 01:10
 *
 */

/**
 * The Template for displaying product archives, including the main shop page which is a post type archive
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/archive-product.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce\Templates
 * @version 3.4.0
 */

defined('ABSPATH') || exit;

$shop_filter_sidebar = get_theme_mod('shop-filter-sidebar', esc_attr(1));

if (!empty($_GET['filter'])):

    $shop_filter_sidebar = $_GET['filter'];

endif;

$shop_filter_sidebar_type = get_theme_mod('shop-filter-sidebar-type', esc_attr('fixed'));

if (!empty($_GET['filter_type'])):

    $shop_filter_sidebar_type = $_GET['filter_type'];

endif;

$shop_filter_toggle_type = get_theme_mod('shop-filter-toggle-type', esc_attr('default'));

if (!empty($_GET['filter_toggle_type'])):

    $shop_filter_toggle_type = $_GET['filter_toggle_type'];

endif;

$shop_filter_sidebar_alignment = get_theme_mod('shop-filter-sidebar-alignment', esc_attr('left'));

if (!empty($_GET['filter_direction'])):

    $shop_filter_sidebar_alignment = $_GET['filter_direction'];

endif;

$shop_style = get_theme_mod('shop-style', esc_attr('default'));

if (!empty($_GET['style'])):

    $shop_style = $_GET['style'];

endif;

$classes = array();

array_push($classes, 'shop-style-' . $shop_style);

array_push($classes, 'loop-' . $shop_filter_sidebar_alignment);

$classes = implode(' ', $classes);

get_header('shop');

/**
 * Hook: woocommerce_before_main_content.
 *
 * @hooked woocommerce_output_content_wrapper - 10 (outputs opening divs for the content)
 * @hooked woocommerce_breadcrumb - 20
 * @hooked WC_Structured_Data::generate_website_data() - 30
 */
do_action('woocommerce_before_main_content');

/**
 * Hook: woocommerce_archive_description.
 *
 * @hooked woocommerce_taxonomy_archive_description - 10
 * @hooked woocommerce_product_archive_description - 10
 */
do_action('woocommerce_archive_description');

if (woocommerce_product_loop()) { ?>

    <header class="shop-header">

        <div class="left-side">

            <?php

            if ($shop_filter_sidebar_type === 'fixed' && $shop_filter_sidebar && $shop_filter_toggle_type === 'minimal'):

                ?>

                <button class="filter-sidebar-toggle">

                    <i class="ri-sound-module-line right-icon"></i>

                </button>

            <?php

            endif;

            woocommerce_result_count();

            ?>

        </div>

        <div class="right-side">

            <?php

            woocommerce_catalog_ordering();

            if ($shop_filter_sidebar_type === 'fixed' && $shop_filter_sidebar && $shop_filter_toggle_type === 'default' && class_exists('JKD_Core')):

                ?>

                <button class="jkd-button default-style animation-slide filter-sidebar-toggle">

                        <span>

                            <span>

                                <?php echo esc_html__('Filter', 'qreatix'); ?>

                                <i class="ri-sound-module-line right-icon"></i>

                            </span>

                        </span>

                </button>

            <?php endif; ?>

        </div>

    </header>

    <div class="loop-container <?php if ($shop_filter_sidebar_type === 'default' && $shop_filter_sidebar): ?> sidebar-enabled <?php endif; ?>">

        <div class="shop-loop-wrapper <?php echo esc_attr($classes); ?>">

            <?php

            if ($shop_filter_sidebar_type === 'default' && $shop_filter_sidebar && is_active_sidebar('shop-filters-sidebar')):

                ?>

                <div class="filter-sidebar">

                    <div class="sidebar-inner">

                        <?php

                        dynamic_sidebar('shop-filters-sidebar');

                        ?>

                    </div>

                </div>

            <?php

            endif;

            /**
             * Hook: woocommerce_before_shop_loop.
             *
             * @hooked woocommerce_output_all_notices - 10
             * @hooked woocommerce_result_count - 20
             * @hooked woocommerce_catalog_ordering - 30
             */
            do_action('woocommerce_before_shop_loop');

            ?>

            <div class="loop-inner">

                <?php

                woocommerce_product_loop_start();

                if (wc_get_loop_prop('total')) {
                    while (have_posts()) {
                        the_post();

                        /**
                         * Hook: woocommerce_shop_loop.
                         */
                        do_action('woocommerce_shop_loop');

                        wc_get_template_part('content', 'product');
                    }
                }

                woocommerce_product_loop_end();

                /**
                 * Hook: woocommerce_after_shop_loop.
                 *
                 * @hooked woocommerce_pagination - 10
                 */
                do_action('woocommerce_after_shop_loop');

                ?>

            </div>

        </div>

    </div>

    <?php

} else {

    /**
     * Hook: woocommerce_no_products_found.
     *
     * @hooked wc_no_products_found - 10
     */
    do_action('woocommerce_no_products_found');

}

/**
 * Hook: woocommerce_after_main_content.
 *
 * @hooked woocommerce_output_content_wrapper_end - 10 (outputs closing divs for the content)
 */
do_action('woocommerce_after_main_content');

/**
 * Hook: woocommerce_sidebar.
 *
 * @hooked woocommerce_get_sidebar - 10
 */
do_action('woocommerce_sidebar');

get_footer('shop');
