<?php
/*
 * *************************************************************************
 *  * Copyright (C) JK-Studio, Inc - All Rights Reserved
 *  *
 *  * @file        related.php
 *  * @author      Alexander Poslushnyak
 *  * @website     https://jk-studio-dev.com/
 *  * @date        18/09/2021, 01:10
 *
 */

/**
 * Related Products
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/single-product/related.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see         https://docs.woocommerce.com/document/template-structure/
 * @package     WooCommerce\Templates
 * @version     3.9.0
 */

if (!defined('ABSPATH')) {
    exit;
}

if ($related_products) : ?>

    <div class="related-wrapper product-slider-wrapper bottom-item"
         data-slider-type="<?php echo esc_attr('related'); ?>"
         data-slides="<?php echo esc_attr('3'); ?>">

        <section class="related product-slider-inner">

            <?php

            $heading = apply_filters('woocommerce_product_related_products_heading', __('Related Products', 'qreatix'));

            ?>

            <div class="related-header product-slider-header">

                <?php if ($heading) : ?>

                    <div class="title-wrapper">

                        <div class="pagination-numbers">

                        </div>

                        <h5 class="related-title product-slider-title">

                            <?php echo esc_html($heading); ?>

                        </h5>

                    </div>

                <?php endif; ?>

                <div class="related-navigation product-slider-navigation">

                    <div class="navigation-button navigation-button-prev">

                        <i class="ri-arrow-drop-left-line"></i>

                    </div>

                    <div class="navigation-button navigation-button-next">

                        <i class="ri-arrow-drop-right-line"></i>

                    </div>

                </div>

            </div>

            <div class="swiper-container related-slider product-slider">

                <div class="swiper-wrapper">

                    <?php foreach ($related_products as $related_product) : ?>

                        <div class="swiper-slide">

                            <?php

                            $id = $related_product->get_id();

                            $product = wc_get_product($id);

                            $thumbnail_id = get_post_thumbnail_id($id);

                            $product_title = $product->get_title();

                            $product_price = $product->get_price_html();

                            $product_permalink = $product->get_permalink();

                            ?>

                            <div class="product-slide-inner">

                                <a href="<?php echo esc_url($product_permalink); ?>" class="link-overlay"></a>

                                <?php if (!empty($thumbnail_id)): ?>

                                    <a class="thumbnail-wrapper" href="<?php echo esc_url($product_permalink); ?>">

                                        <?php

                                        if (class_exists('JKD_Helper')):

                                            echo JKD_Helper::render_image($thumbnail_id,
                                                'jk-square-size-extra-small',
                                                array('sizes' => implode(',', array(
                                                    '(max-width: 300px) 300px',
                                                )),
                                                    'srcset' => implode(',', array(
                                                        esc_url(wp_get_attachment_image_url($thumbnail_id, 'jk-square-size-extra-small')) . ' 300w',
                                                    )),
                                                    'loading' => 'lazy',
                                                    'alt' => $product_title
                                                ), false);

                                        else:

                                            ?>

                                            <img src="<?php echo esc_url(wp_get_attachment_image_url($thumbnail_id, 'thumbnail')) ?>"
                                                 alt="<?php echo esc_html(get_the_title()); ?>">

                                        <?php

                                        endif;

                                        ?>

                                    </a>

                                <?php endif; ?>

                                <div class="product-body">

                                    <h6 class="product-title">

                                        <?php echo esc_html($product_title); ?>

                                    </h6>

                                    <div class="price-wrapper">

                                        <?php echo JKD_Theme::check_for_empty($product_price); ?>

                                    </div>

                                </div>

                            </div>

                        </div>

                    <?php endforeach; ?>

                </div>

            </div>

        </section>

    </div>

<?php
endif;

wp_reset_postdata();
